.. Django CKEditors documentation master file, created by
   sphinx-quickstart on Tue Apr  9 10:13:05 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../../README.rst


.. toctree::
   :hidden:
   :titlesonly:

   how-to/index-how-to
   discussion/index-discussion



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
